@@ -6,7 +6,7 @@ class ReactiveCommand(IntEnum):
     Call = 0x1
     RemoteOutput = 0x2
     Load = 0x3
-    Ping = 0x4
+    Reset = 0x4
     RegisterEntrypoint = 0x5
     Output = 0x6  # called by software modules in SGX and Native
     RemoteRequest = 0x7
@@ -34,6 +34,6 @@ class ReactiveResult(IntEnum):
 class ReactiveEntrypoint(IntEnum):
     SetKey = 0x0
     Attest = 0x1
-    Exit = 0x2
+    Disable = 0x2
     HandleInput = 0x3
     HandleHandler = 0x4
